package Sah::SchemaR::date::dow_nums::id;

our $DATE = '2021-08-04'; # DATE
our $VERSION = '0.007'; # VERSION

our $rschema = do{my$var={base=>"array",clsets_after_base=>[{description=>"\nSee also <pm:Sah::Schema::date::dow_num::id> which is the schema for the\nelements.\n\nSee also related schemas that coerce from other locales, e.g.\n<pm:Sah::Schema::date::dow_nums> (English),\n<pm:Sah::Schema::date::dow_num::en_or_id> (English/Indonesian), etc.\n\n",examples=>[{valid=>1,validated_value=>[],value=>""},{summary=>"Has number not in 1-7",valid=>0,value=>0},{valid=>1,validated_value=>[1],value=>1},{valid=>1,validated_value=>[1,7],value=>"1,7"},{summary=>"Contains undef",valid=>0,value=>[1,undef]},{valid=>1,value=>[1,7]},{valid=>1,validated_value=>[1,7],value=>["Sen","MinggU"]},{valid=>1,validated_value=>[1,7],value=>"Sn,MG"},{summary=>"Has number not in 1-7",valid=>0,value=>"1,7,8"},{summary=>"Has number not in 1-7",valid=>0,value=>[1,7,8]}],of=>["date::dow_num::id",{req=>1}],summary=>"Array of required day-of-week numbers (1-7, 1=Monday, like DateTime, with coercions)","x.completion"=>["date_dow_nums_id"],"x.perl.coerce_rules"=>["From_str::comma_sep"]}],clsets_after_type=>['$var->{clsets_after_base}[0]'],"clsets_after_type.alt.merge.merged"=>['$var->{clsets_after_base}[0]'],resolve_path=>["array"],type=>"array",v=>2};$var->{clsets_after_type}[0]=$var->{clsets_after_base}[0];$var->{"clsets_after_type.alt.merge.merged"}[0]=$var->{clsets_after_base}[0];$var};

1;
# ABSTRACT: Array of required day-of-week numbers (1-7, 1=Monday, like DateTime, with coercions)

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::SchemaR::date::dow_nums::id - Array of required day-of-week numbers (1-7, 1=Monday, like DateTime, with coercions)

=head1 VERSION

This document describes version 0.007 of Sah::SchemaR::date::dow_nums::id (from Perl distribution Sah-Schemas-Date-ID), released on 2021-08-04.

=head1 DESCRIPTION

This module is automatically generated by Dist::Zilla::Plugin::Sah::Schemas during distribution build.

A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema without having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Date-ID>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Date-ID>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Date-ID>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
